pub enum CargoTomlError {
NoTable {
table_name: String,
},
NoValue {
value_name: String,
},
SetVersion {
name: String,
version: String,
},
}Expand description
The error details related the contents of a Cargo.toml file.
Variants
NoTable
Error related to a missing table in a Cargo.toml file.
NoValue
Error related to a missing value in a Cargo.toml file.
SetVersion
Error related to failed attempt to set the version for a package or a dependency.